/*
 * Copyright (c) 2010 David McIntosh <dmcintosh@df12.net>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#import <AppKit/AppKit.h>
#import "util.h"
#import "NSDate+GanttAdditions.h"

@interface GanttTask : NSObject <NSCoding>
{
    NSInteger       _tag;
    NSDate         *_startDate;
    NSDate         *_endDate;
    float           _completion;
    NSString       *_name;
    NSMutableArray *_children;
    GanttTask      *_parent;
}

+ (GanttTask *)taskWithTag:(NSInteger)tag 
                 startDate:(NSDate *)startDate 
                   endDate:(NSDate *)endDate 
                completion:(float)completion;
- (id)initWithTag:(NSInteger)tag 
        startDate:(NSDate *)startDate 
          endDate:(NSDate *)endDate 
       completion:(float)completion;
- (BOOL)isEqualToTask:(GanttTask *)aTask;
- (NSInteger)tag;
- (void)setTag:(NSInteger)val;
- (NSDate *)startDate;
- (void)setStartDate:(NSDate *)val;
- (NSDate *)endDate;
- (void)setEndDate:(NSDate *)val;
- (float)completion;
- (void)setCompletion:(float)val;
- (NSString *)name;
- (void)setName:(NSString *)val;
- (NSArray *)children;
- (NSInteger)childCount;
- (void)addChild:(GanttTask *)task;
- (void)addChildren:(NSArray *)tasks;
- (void)removeChild:(GanttTask *)task;
- (GanttTask *)childAtIndex:(NSInteger)index;
- (void)setParent:(GanttTask *)task;
- (GanttTask *)parent;

@end
